<?php declare(strict_types=1);

namespace EuKit\Base;

use EuKit\Base\Interfaces\ViewModel;
use Infomaker\Everyware\NewsML\Objects\TeaserItem;

/**
 * Class Teaser
 * @package EuKit\Base
 */
class Teaser implements ViewModel
{
    /**
     * @var NewsMLArticle
     */
    private $article;

    public function __construct(NewsMLArticle $article)
    {
        $this->article = $article;
    }

    protected function createTeaser(TeaserItem $teaser): array
    {
        $image = $teaser->hasImage() ? new Image($teaser->getImage()) : null;

        $teaserData = array_replace($teaser->toArray(), [
            'image' => $image instanceof Image ? $image->getViewData() : null,
        ]);

        return array_filter($teaserData);
    }

    public function getViewData(): array
    {
        $teaser = $this->article->getNewsMLTeaser();
        $viewData = array_replace([
            'uuid' => $this->article->getSingleValue('uuid'),
            'pubdate' => $this->article->getPubDate()->diffForHumans(),
            'pubdatetime' => $this->article->getPubDate(),
            'headline' => $this->article->getSingleValue('headline'),
            'leadin' => $this->article->getSingleValue('leadin'),
            'Authors' => $this->article->getSingleValue('Authors'),
            'permalink' => $this->article->getSingleValue('permalink'),
            'sectionName' => $this->article->getSingleValue('relatedconceptsectionname'),
            'categoriesName' => $this->article->getSingleValue('relatedconceptcategoriesname'),
            'tagsName' => $this->article->getSingleValue('relatedconcepttagsname'),
        ], $teaser instanceof TeaserItem ? $this->createTeaser($teaser) : []);

        return $viewData;
    }
}
